;;; -*- mode:lisp; package:(graph global 1000); base:10.; -*- ;;; 

;;; Automatically create the CT: logical pathname host if it doesn't
;;; already exist.  The original is in CT: CTLISP; CTLOAD.LISP.
(unless (fs:get-pathname-host "CT" 't)
  (let ((host (send fs:fdefine-file-pathname :host)))
    (if (typep host 'fs:logical-host) (setq host (send host :host)))
    (format t "~&Setting CT physical host to ~A." host)
    (fs:set-logical-pathname-host
      "CT" :physical-host host :translations
      #+LMI
      '(("ADA;"       "CT-ADA.ADA;")		;Ada programs
	("BROWSER;"   "CT-ADA.BROWSER;")	;Doc browser system
	("BUILD;"     "CT-ADA.BUILD;")		;System building tools
	("CT;"	      "CT-ADA.CT;")		;Temporary files
	("CTLISP;"    "CT-ADA.CTLISP;")		;Lisp compatibility files
	("DEBUG;"     "CT-ADA.DEBUG;")		;Debugger
	("DOC;"	      "CT-ADA.DOC;")		;Documentation for browser
	("DOC; *;"    "CT-ADA.DOC.*;")		;Doc subdirectories
	("EDITOR;"    "CT-ADA.EDITOR;")		;Zwei Ada mode
	("GRAPH;"     "CT-ADA.GRAPH;")		;Graph editor
	("INTERP;"    "CT-ADA.INTERP;")		;Ada interpreter
	("LMFONTS;"   "CT-ADA.LMFONTS;")	;Additional fonts
	("TOOLS;"     "CT-ADA.TOOLS;")		;Random tools
	("WINDOW;"    "CT-ADA.WINDOW;")		;Window enhancements
	)
      #+Symbolics ; to work in rel 6 at c*t
      '(("GRAPH;"     "//mnt//consult//soley//graph//")))))

(defsystem GRAPH
  (:name		"Graph")
  (:pathname-default	"CT: GRAPH;")
  (:module Utils	("gray"			;Gray border code.
			 "track"		;Tracking-window-mixin
			 "utils"		;Various macros
			 "tvgraph"		;tv: graphics stuff
			 "vector"))		;Vector character draw
  (:module Low		("node"
			 "arc"
			 "gwindow"))
  (:module High		("draw"))
  (:module User		("user"			;RUN, SETUP
			 "layout"))		;Additional layout stuff.
  (:module End		("end"))		;Compilation

  
  (:compile-load Utils)
  (:compile-load Low  (:fasload Utils)
		      (:fasload Utils))
  (:compile-load High (:fasload Low Utils)
		      (:fasload Low Utils))
  (:compile-load User (:fasload High Low Utils)
		      (:fasload High Low Utils))
  (:compile-load End  (:fasload High Low Utils User)
		      (:fasload High Low Utils User))

  )
